JeffPong
========

This is a simple implementation of the classic video game written in Python with the Pygame library.


Installation
------------

To install, simply run `pip install JPong`. That's it! To start playing, enter the command `jpong`
in a terminal.

Play
----

To play, use the up and down array keys on your keyboard to control the paddle. To pause, press P.
To continue playing, press S. To quit, press the escape key, or select the "X" in the top right
of the game window.

Modifications and Bugs
----------------------

Please feel free to email me about problems with the game or suggestions for modifications. I'm always
open to new ideas.
